@@ -2,7 +2,9 @@
 
 import getpass
 import json
-from pathlib import Path
+from json import JSONDecodeError
+
+from deepchainapps.utils.common import _create_config_file, _create_deechpain_folder
 
 
 def login_args_configuration(sub_parser):
@@ -16,17 +18,21 @@ def login_args_configuration(sub_parser):
 def login(_):
     """
     Login function that create a subdirectory and store the token
+    We first create .deepchain folder, then config file if not exist
+    The open the file in r+ mode to not erase previous info
     """
-    path = Path.home().joinpath(".deep-chain")
-    path.mkdir(exist_ok=True)
-    path = path.joinpath("config")
+    root_path = _create_deechpain_folder()
+    path = _create_config_file(root_path)
 
     data = {}
-    with open(path, "w+") as config_file:
+    with open(path, "r+") as config_file:
         try:
             data = json.load(config_file)
-        finally:
+        except JSONDecodeError:
             pass
+
         data["pat"] = getpass.getpass("PAT:")
         data["size_limit"] = 40
-        json.dump(data, config_file)
+        config_file.seek(0)  # reset file position to the beginning.
+        json.dump(data, config_file, indent=4)
+        config_file.truncate()  # remove remaining part
