@@ -12,11 +12,11 @@ import pkg_resources
 import requests
 from deepchainapps import ConfigNotFoundError, log
 from deepchainapps.utils.common import (
+    get_app_configuration,
     get_app_info,
-    get_scorer_configuration,
     update_app_status,
 )
-from deepchainapps.utils.validation import _check_checkpoint_files, _check_scorer_files
+from deepchainapps.utils.validation import _check_app_files, _check_checkpoint_files
 
 
 def deploy_args_configuration(sub_parser):
@@ -70,8 +70,8 @@ def deploy(args):
             return
 
     log.info("Check files before upload...")
-    _check_scorer_files(app_name)
-    score_configuration = get_scorer_configuration(app_name)
+    _check_app_files(app_name)
+    score_configuration = get_app_configuration(app_name)
 
     req = upload_code(app_dir, args, pat, url, score_configuration)
     if req.status_code != 200:
