@@ -40,9 +40,9 @@ def _check_file_extension(folder_path: Path, extension_list: List) -> bool:
     return model_found
 
 
-def _check_scorer_files(app_name: str):
+def _check_app_files(app_name: str):
     """
-    Check if the name of the scorer has not been modified to be upload
+    Check if the name of the app has not been modified to be upload
     on the plateform
     """
     app_dir = Path(get_app_info(app_name))
@@ -55,7 +55,7 @@ def _check_scorer_files(app_name: str):
 
     _check_init(app_dir)
     _check_init(app_dir.joinpath("src"))
-    _check_scorer(app_dir.joinpath("src"))
+    _check_app(app_dir.joinpath("src"))
     _check_module(app_dir, app_name)
 
     return
@@ -70,12 +70,12 @@ def _check_init(app_dir: Path) -> None:
         )
 
 
-def _check_scorer(app_dir: Path) -> None:
-    """Check if scorer file if in the app folder"""
-    path_scorer = app_dir.joinpath("scorer.py")
+def _check_app(app_dir: Path) -> None:
+    """Check if app file if in the app folder"""
+    path_scorer = app_dir.joinpath("app.py")
     if not path_scorer.is_file():
-        similar_file = _find_similar_file(app_dir, "score")
-        message = "The scorer filename must be scorer.py"
+        similar_file = _find_similar_file(app_dir, "app")
+        message = "The app filename must be app.py"
         if similar_file is not None:
             message += f", found this similar file instead : {similar_file}"
 
@@ -83,19 +83,17 @@ def _check_scorer(app_dir: Path) -> None:
 
 
 def _check_module(app_dir: Path, app_name: str) -> None:
-    """Check if scorer module contains Score class"""
+    """Check if app module contains App class"""
     # append current path to the pkg to find the app
     # as a module
 
     sys.path.append(str(app_dir.parent))
-    mod = importlib.import_module(app_name + ".src.scorer")
+    mod = importlib.import_module(app_name + ".src.app")
     avail_members = dir(mod)
     sys.path.pop(-1)
 
-    if "Scorer" not in avail_members:
-        raise ModuleNotFoundError(
-            "You must have a Scorer class in your scorer.py module"
-        )
+    if "App" not in avail_members:
+        raise ModuleNotFoundError("You must have a App class in your app.py module")
 
 
 def _find_similar_file(path_folder: Path, pattern: str) -> str:
